package Microsoft::AdCenter::V7::ReportingService::AgeGenderDemographicReportColumn;
# Copyright (C) 2012 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

=head1 NAME

Microsoft::AdCenter::V7::ReportingService::AgeGenderDemographicReportColumn - Represents "AgeGenderDemographicReportColumn" in Microsoft AdCenter Reporting Service.

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=head1 ENUMERATION VALUES

    AccountName
    AccountNumber
    AdDistribution
    AdGroupName
    AgeGroup
    CampaignName
    EstimatedClickPercent
    EstimatedCtr
    EstimatedImpressionPercent
    Gender
    Language
    LanguageAndRegion
    TimePeriod

=cut

sub AccountName {
    return 'AccountName';
}

sub AccountNumber {
    return 'AccountNumber';
}

sub AdDistribution {
    return 'AdDistribution';
}

sub AdGroupName {
    return 'AdGroupName';
}

sub AgeGroup {
    return 'AgeGroup';
}

sub CampaignName {
    return 'CampaignName';
}

sub EstimatedClickPercent {
    return 'EstimatedClickPercent';
}

sub EstimatedCtr {
    return 'EstimatedCtr';
}

sub EstimatedImpressionPercent {
    return 'EstimatedImpressionPercent';
}

sub Gender {
    return 'Gender';
}

sub Language {
    return 'Language';
}

sub LanguageAndRegion {
    return 'LanguageAndRegion';
}

sub TimePeriod {
    return 'TimePeriod';
}

1;
